@@ -1,7 +1,10 @@
 import jwt
 from jwt.exceptions import ExpiredSignatureError, DecodeError, InvalidTokenError
 
+from square_authentication.configuration import global_object_square_logger
 
+
+@global_object_square_logger.auto_logger()
 def get_jwt_payload(token, secret_key):
     try:
         # Decode the token and verify the signature
